summaryrefslogtreecommitdiffstats
path: root/tests/acceptance/features/core/NextcloudTestServerContext.php
diff options
context:
space:
mode:
Diffstat (limited to 'tests/acceptance/features/core/NextcloudTestServerContext.php')
-rw-r--r--tests/acceptance/features/core/NextcloudTestServerContext.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/tests/acceptance/features/core/NextcloudTestServerContext.php b/tests/acceptance/features/core/NextcloudTestServerContext.php
index f8d13a656b9..ff1296ba18a 100644
--- a/tests/acceptance/features/core/NextcloudTestServerContext.php
+++ b/tests/acceptance/features/core/NextcloudTestServerContext.php
@@ -40,12 +40,12 @@ use Behat\Behat\Hook\Scope\BeforeScenarioScope;
*
* The Nextcloud server is provided by an instance of NextcloudTestServerHelper;
* its class must be specified when this context is created. By default,
* "NextcloudTestServerLocalHelper" is used, although that can be customized
* using the "nextcloudTestServerHelper" parameter in "behat.yml". In the same
* way, the parameters to be passed to the helper when it is created can be
* customized using the "nextcloudTestServerHelperParameters" parameter, which
* is an array (without keys) with the value of the parameters in the same order
* as in the constructor of the helper class (by default, [ ]).
*
* Example of custom parameters in "behat.yml":
* default:
@@ -73,7 +73,7 @@ class NextcloudTestServerContext implements Context {
* @param array $nextcloudTestServerHelperParameters the parameters for the
* constructor of the $nextcloudTestServerHelper class.
*/
- public function __construct($nextcloudTestServerHelper = "NextcloudTestServerLocalHelper",
+ public function __construct($nextcloudTestServerHelper = "NextcloudTestServerLocalBuiltInHelper",
$nextcloudTestServerHelperParameters = [ ]) {
$nextcloudTestServerHelperClass = new ReflectionClass($nextcloudTestServerHelper);
@@ -40,12 +40,12 @@ use Behat\Behat\Hook\Scope\BeforeScenarioScope;
* The Nextcloud server is provided by an instance of NextcloudTestServerHelper;
* its class must be specified when this context is created. By default,
- * "NextcloudTestServerLocalHelper" is used, although that can be customized
- * using the "nextcloudTestServerHelper" parameter in "behat.yml". In the same
- * way, the parameters to be passed to the helper when it is created can be
- * customized using the "nextcloudTestServerHelperParameters" parameter, which
- * is an array (without keys) with the value of the parameters in the same order
- * as in the constructor of the helper class (by default, [ ]).
+ * "NextcloudTestServerLocalBuiltInHelper" is used, although that can be
+ * customized using the "nextcloudTestServerHelper" parameter in "behat.yml". In
+ * the same way, the parameters to be passed to the helper when it is created
+ * can be customized using the "nextcloudTestServerHelperParameters" parameter,
+ * which is an array (without keys) with the value of the parameters in the same
+ * order as in the constructor of the helper class (by default, [ ]).
*
* Example of custom parameters in "behat.yml":